@@ -1,4 +1,10 @@
 package Tapper::Cmd::Queue;
+BEGIN {
+  $Tapper::Cmd::Queue::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Cmd::Queue::VERSION = '4.0.1';
+}
 use Moose;
 
 use DateTime;
@@ -8,43 +14,8 @@ use Tapper::Model 'model';
 extends 'Tapper::Cmd';
 
 
-=head1 NAME
-
-Tapper::Cmd::Queue - Backend functions for manipluation of queues in the database
-
-=head1 SYNOPSIS
-
-This project offers backend functions for all projects that manipulate
-queues in the database. This module handles the testrun part.
-
-    use Tapper::Cmd::Queue;
-
-    my $bar = Tapper::Cmd::Queue->new();
-    $bar->add($testrun);
-    ...
-
-=head1 FUNCTIONS
-
-=head2 add
-
-Add a new queue to database.
-
-=cut
 
 
-=head2 add
-
-Add a new queue.
--- required --
-* name - string
-* priority - int
-
-@param hash ref - options for new queue
-
-@return success - queue id
-@return error   - undef
-
-=cut
 
 sub add {
         my ($self, $args) = @_;
@@ -61,17 +32,6 @@ sub add {
 }
 
 
-=head2 update
-
-Changes values of an existing queue. 
-
-@param int      - queue id
-@param hash ref - overwrite these options
-
-@return success - queue id
-@return error   - undef
-
-=cut
 
 sub update {
         my ($self, $id, $args) = @_;
@@ -89,6 +49,70 @@ sub update {
         return $retval;
 }
 
+
+sub del {
+        my ($self, $id) = @_;
+        my $queue = model('TestrunDB')->resultset('Queue')->find($id);
+        $queue->is_deleted(1);
+        $queue->active(0);
+        $queue->update;
+        return 0;
+}
+
+1; # End of Tapper::Cmd::Testrun
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Cmd::Queue
+
+=head1 SYNOPSIS
+
+This project offers backend functions for all projects that manipulate
+queues in the database. This module handles the testrun part.
+
+    use Tapper::Cmd::Queue;
+
+    my $bar = Tapper::Cmd::Queue->new();
+    $bar->add($testrun);
+    ...
+
+=head1 NAME
+
+Tapper::Cmd::Queue - Backend functions for manipluation of queues in the database
+
+=head1 FUNCTIONS
+
+=head2 add
+
+Add a new queue to database.
+
+=head2 add
+
+Add a new queue.
+-- required --
+* name - string
+* priority - int
+
+@param hash ref - options for new queue
+
+@return success - queue id
+@return error   - undef
+
+=head2 update
+
+Changes values of an existing queue.
+
+@param int      - queue id
+@param hash ref - overwrite these options
+
+@return success - queue id
+@return error   - undef
+
 =head2 del
 
 Delete a queue with given id. Its named del instead of delete to
@@ -99,34 +123,17 @@ prevent confusion with the buildin delete function.
 @return success - 0
 @return error   - error string
 
-=cut
-
-sub del {
-        my ($self, $id) = @_;
-        my $testrun = model('TestrunDB')->resultset('Queue')->find($id);
-        $testrun->delete();
-        return 0;
-}
-
-
-
 =head1 AUTHOR
 
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
+AMD OSRC Tapper Team <tapper@amd64.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to C<osrc-sysin at elbe.amd.com>, or through
-the web interface at L<https://osrc/bugs>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
 
+This is free software, licensed under:
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
+  The (two-clause) FreeBSD License
 
 =cut
 
-1; # End of Tapper::Cmd::Testrun
